"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.commandHelp = exports.dependencies = void 0;

const multiline_ts_1 = __importDefault(require("multiline-ts"));

const index_1 = __importDefault(require("./index.cjs"));

const argvParser_1 = __importDefault(require("./argvParser.cjs"));

exports.dependencies = {
  console,
  convertExtension: index_1.default
};
exports.commandHelp = multiline_ts_1.default`
  Convert JS source file extensions

  Usage: npx convert-extension [--help] <extension> <path> [--input-extension=<value>]
  Description:
    Converts any files in <path> with the specified input extension (default "js") and their relative imports to <extension>.
    Will also convert source maps, if they exist.

  Arguments:
    <extension>
      Extension to rename to e.g. "mjs", "cjs"

    <path>
      Directory containing files to rename

  Options:
    --help
      Display this message

    --input-extension=<value>
      Extension of files to process, default "js"
`;
/** Tests snippets as a command */

async function convertExtensionCommand(argv) {
  const {
    args,
    options
  } = argvParser_1.default(argv);

  if (options.help) {
    exports.dependencies.console.log(exports.commandHelp);
    return;
  }

  if (args.length < 1) {
    throw new Error('<extension> must be supplied');
  }

  if (args.length < 2) {
    throw new Error('<path> must be supplied');
  }

  if (options['input-extension'] === true) {
    throw new Error('--input-extension must have a value');
  }

  const outputExtension = args[0];
  const path = args[1];
  const inputExtension = options['input-extension'] || 'js';
  await exports.dependencies.convertExtension(path, inputExtension, outputExtension);
}

exports.default = convertExtensionCommand;
//# sourceMappingURL=convertExtensionCommand.cjs.map
