"use strict";

var __createBinding = this && this.__createBinding || (Object.create ? function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  Object.defineProperty(o, k2, {
    enumerable: true,
    get: function () {
      return m[k];
    }
  });
} : function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  o[k2] = m[k];
});

var __setModuleDefault = this && this.__setModuleDefault || (Object.create ? function (o, v) {
  Object.defineProperty(o, "default", {
    enumerable: true,
    value: v
  });
} : function (o, v) {
  o["default"] = v;
});

var __importStar = this && this.__importStar || function (mod) {
  if (mod && mod.__esModule) return mod;
  var result = {};
  if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);

  __setModuleDefault(result, mod);

  return result;
};

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertFileExtension = exports.ignoreMissingFile = exports.saveFile = exports.sourceMapUrl = exports.components = exports.dependencies = void 0;

const path_1 = __importDefault(require("path"));

const fs_1 = __importDefault(require("fs"));

const core_1 = __importStar(require("@babel/core")),
      babel = core_1;

const glob_1 = __importDefault(require("glob"));

const util_1 = require("util");

const mkdirp_1 = __importDefault(require("mkdirp"));

const plugin_1 = __importDefault(require("./plugin.cjs"));

const {
  chmod,
  stat,
  writeFile,
  unlink
} = fs_1.default.promises;
exports.dependencies = {
  transformFile: (core_1.default || babel).transformFileAsync,
  glob: util_1.promisify(glob_1.default),
  chmod,
  console,
  mkdirp: mkdirp_1.default,
  stat,
  writeFile,
  unlink
};
exports.components = {
  saveFile,
  convertFileExtension
};
/** Returns a source map annotation line */

function sourceMapUrl(filename) {
  return `\n//# sourceMappingURL=${path_1.default.basename(filename)}\n`;
}

exports.sourceMapUrl = sourceMapUrl;
/** Saves a file, creating its directory if needed */

async function saveFile(filePath, data) {
  await exports.dependencies.mkdirp(path_1.default.dirname(filePath));
  await exports.dependencies.writeFile(filePath, data);
}

exports.saveFile = saveFile;
/** Awaits a promise, ignoring missing file errors  */

async function ignoreMissingFile(promise) {
  try {
    await promise;
  } catch (error) {
    if (error.code !== 'ENOENT') {
      throw error;
    }
  }
}

exports.ignoreMissingFile = ignoreMissingFile;
/** Converts a file with its imports and source map to a new extension */

async function convertFileExtension(inputFilename, inputExtension, outputExtension, options) {
  const outputFilename = inputFilename.replace(/\..+$/, `.${outputExtension}`);
  const result = await exports.dependencies.transformFile(inputFilename, Object.assign(Object.assign({}, options), {
    caller: {
      name: '@babel/cli'
    },
    plugins: [[plugin_1.default, {
      outputExtension,
      inputExtension
    }]],
    sourceMaps: true
  }));

  if (!result) {
    throw new Error(`Could not compile file ${inputFilename}`);
  }

  let code = String(result.code);

  if (result.map) {
    const outputMapFilename = outputFilename + '.map';
    code = code + sourceMapUrl(outputMapFilename);
    result.map.file = path_1.default.basename(outputFilename);
    await exports.components.saveFile(outputMapFilename, JSON.stringify(result.map));
  }

  await exports.components.saveFile(outputFilename, code);
  await exports.dependencies.chmod(outputFilename, (await exports.dependencies.stat(inputFilename)).mode);
  const inputMapFilename = inputFilename + '.map';
  await exports.dependencies.unlink(inputFilename);
  await ignoreMissingFile(exports.dependencies.unlink(inputMapFilename));
}

exports.convertFileExtension = convertFileExtension;
/** Converts a directory of files to a new extension */

async function convertExtension(directory, inputExtension, outputExtension, options = {}) {
  const filenames = await exports.dependencies.glob(path_1.default.join(directory, `**/*.${inputExtension}`));

  for (const filename of filenames) {
    await exports.components.convertFileExtension(filename, inputExtension, outputExtension, options);
  }
}

exports.default = convertExtension;
//# sourceMappingURL=index.cjs.map
