"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
/** Escape regex special characters in a string */

function escapeRegex(value) {
  return value.replace(/[|\\{}()[\]^$+*?.]/g, '\\$&').replace(/-/g, '\\x2d');
}

exports.default = (babel, options) => ({
  visitor: {
    ImportDeclaration: nodePath => {
      const node = nodePath.node;
      const arg = node.source; // Ignore absolute imports and already converted extensions

      if (!arg.value.match(/^\./) || arg.value.match(new RegExp(`\.${escapeRegex(options.outputExtension)}$`))) {
        return;
      }

      nodePath.replaceWith(babel.types.importDeclaration(node.specifiers, babel.types.stringLiteral(arg.value.replace(new RegExp(`\.${escapeRegex(options.inputExtension)}$|$`), `.${options.outputExtension}`))));
    },
    CallExpression: nodePath => {
      const node = nodePath.node;
      const callee = node.callee;
      const arg = node.arguments[0];

      if (callee.type !== 'Identifier' || callee.name !== 'require' || node.arguments.length !== 1 || arg.type !== 'StringLiteral') {
        return;
      } // Ignore absolute imports and already converted extensions


      if (!arg.value.match(/^\./) || arg.value.match(new RegExp(`\.${escapeRegex(options.outputExtension)}$`))) {
        return;
      }

      nodePath.replaceWith(babel.types.callExpression(callee, [babel.types.stringLiteral(arg.value.replace(new RegExp(`\.${escapeRegex(options.inputExtension)}$|$`), `.${options.outputExtension}`))]));
    }
  }
});
//# sourceMappingURL=plugin.cjs.map
